@@ -76,7 +76,7 @@ QString OctaveExpression::internalCommand()
 
     if (!isInternal())
     {
-        QStringList cmdWords = cmd.split(QRegularExpression(QStringLiteral("\\b")), QString::SkipEmptyParts);
+        QStringList cmdWords = cmd.split(QRegularExpression(QStringLiteral("\\b")), Qt::SkipEmptyParts);
         if (!cmdWords.contains(QLatin1String("help")) && !cmdWords.contains(QLatin1String("completion_matches")))
         {
             for (const QString& plotCmd : plotCommands)
@@ -178,7 +178,7 @@ QString OctaveExpression::internalCommand()
     while(tmpCmd[0] == QLatin1Char('\n'))
         tmpCmd.remove(0, 1);
 
-    cmd = tmpCmd;
+    cmd = std::move(tmpCmd);
     cmd.replace(QLatin1String(";\n"), QLatin1String(";"));
     cmd.replace(QLatin1Char('\n'), QLatin1Char(','));
     cmd += QLatin1Char('\n');
